<?php

namespace Drupal\pagedesigner_layout\Plugin\pagedesigner\Handler;

use Drupal\ui_patterns\Definition\PatternDefinition;
use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\FieldHandlerBase;

/**
 * Process entities of type "layout".
 *
 * @PagedesignerHandler(
 *   id = "layout",
 *   name = @Translation("Layout handler"),
 *   types = {
 *      "layout"
 *   },
 * )
 */
class Layout extends FieldHandlerBase {

  /**
   * The layout pattern definition.
   *
   * @var array
   *   The definition of the layout pattern.
   */
  protected $definition = [
    "id" => 'layout',
    "pagedesigner" => 1,
    "icon" => "far fas fa-cube",
    "type" => "layout",
    "category" => 'Layouts',
    "label" => '',
    "description" => '',
  ];

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(&$attachments) {
    if (\Drupal::currentUser()->hasPermission('restful get pagedesigner_layout')) {
      $attachments['library'][] = 'pagedesigner_layout/insert';
    }
    if (\Drupal::currentUser()->hasPermission('restful post pagedesigner_layout')) {
      $attachments['library'][] = 'pagedesigner_layout/add';
    }
    if (\Drupal::currentUser()->hasPermission('restful delete pagedesigner_layout')) {
      $attachments['library'][] = 'pagedesigner_layout/delete';
    }
  }

  /**
   * {@inheritdoc}
   */
  public function collectPatterns(&$patterns) {
    if (\Drupal::currentUser()->hasPermission('restful get pagedesigner_layout')) {
      $nids = \Drupal::entityQuery('pagedesigner_element')->condition('type', 'layout')->execute();
      $definitions = \Drupal::service('plugin.manager.ui_patterns')->getDefinitions();
      foreach ($nids as $nid) {
        $layout = Element::load($nid);
        if ($layout != NULL) {
          $root = $layout->children->entity;
          if ($root != NULL && !empty($definitions[$root->field_pattern->value])) {
            if ($this->elementHandler->isInTheme($definitions[$root->field_pattern->value])) {
              $definition = $this->definition;
              $definition['id'] .= $nid;
              $definition['layout'] = $nid;
              $definition['markup'] = '<div></div>';
              $definition['root'] = $root->id();
              $definition['label'] = $layout->name->value;
              $patterns[$definition['id']] = new PatternDefinition($definition);
            }
          }
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, &$build = []) {

  }

  /**
   * {@inheritdoc}
   */
  public function renderForEdit(Element $entity, &$build = []) {

  }

}
