<?php

namespace Drupal\Tests\pagedesigner_link\Kernel\HandlerTests;

use Drupal\Tests\pagedesigner\Kernel\HandlerTests\PlainFieldHandlerTestBase;

/**
 * Test the "link" handler with a predefined entity defintion.
 *
 * Tests serializing, getting and rendering of the entity.
 *
 * @group pagedesigner
 */
class LinkHandlerTest extends PlainFieldHandlerTestBase {

  /**
   * Define the properties of the entity.
   *
   * @var array
   */
  protected $entityDefinition = [
    'type' => 'link',
    'name' => 'link',
    'langcode' => 'en',
    'field_link' => ['uri' => '/node/1', 'title' => 'link title'],
  ];

  /**
   * Define handler to be tested.
   *
   * @var string
   */
  protected $handlerId = 'link';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    self::$modules[] = 'system';
    self::$modules[] = 'link';
    self::$modules[] = 'linkit';
    self::$modules[] = 'pagedesigner_link';
    parent::setUp();
    $this->installConfig(['link', 'linkit', 'pagedesigner_link']);
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, assert the returned array contains the pagedesigner library.
   */
  protected function collectAttachmentsTest() {
    $attachments = parent::collectAttachmentsTest();
    $this->assertTrue(\in_array('pagedesigner_link/pagedesigner', $attachments['library']));
    return $attachments;
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, assert the returned value is equal to the given value.
   */
  protected function serializeTest() {
    $result = parent::serializeTest();
    $this->assertTrue($result['uri'] == $this->entityDefinition['field_link']['uri']);
    $this->assertTrue($result['title'] == $this->entityDefinition['field_link']['title']);
    return $result;
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, assert the returned value is equal to the given value.
   */
  protected function getTest() {
    $value = parent::getTest();
    $this->assertTrue($value == $this->entityDefinition['field_link']['uri']);
    return $value;
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, check the render array schema and content.
   */
  protected function renderTest() {
    $build = parent::renderTest();
    $this->assertTrue($build['#plain_text'] == $this->entityDefinition['field_link']['uri']);
    return $build;
  }

}
