<?php

namespace Drupal\pagedesigner\Plugin\pagedesigner\Handler;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\FieldHandlerBase;

/**
 * Process entities of type "cell".
 *
 * @PagedesignerHandler(
 *   id = "cell",
 *   name = @Translation("Cell renderer"),
 *   types = {
 *     "cell",
 *   },
 * )
 */
class Cell extends FieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function renderForPublic(Element $entity, &$build) {
    $entity = $entity->loadNewestPublished();
    $listBuild = [];
    if ($entity != NULL) {
      foreach ($entity->children as $item) {
        $listBuild[] = $this->elementHandler->renderForPublic($item->entity);
      }
    }
    $build = $listBuild + $build;

  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, &$build = []) {
    $listBuild = [];
    foreach ($entity->children as $item) {
      $listBuild[] = $this->elementHandler->render($item->entity);
    }
    $build = $listBuild + $build;
  }

  /**
   * {@inheritdoc}
   */
  public function renderForEdit(Element $entity, &$build = []) {
    $listBuild = [];
    foreach ($entity->children as $item) {
      $listBuild[] = $this->elementHandler->renderForEdit($item->entity);
    }
    $build = $listBuild + $build;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, &$result = '') {
    $result = $entity->id();
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, &$list = []) {
    foreach ($entity->children as $item) {
      if ($item->entity != NULL && ($child = $item->entity->loadNewestPublished()) != NULL) {
        $this->elementHandler->getContent($child, $list);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, &$result = []) {
    $data = [];
    foreach ($entity->children as $item) {
      if ($item->entity != NULL) {
        $data[] = $item->entity->id();
      }
    }
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, $data) {
    // Defining build array.
    if (isset($data['order'])) {
      $entity->children->setValue([]);

      foreach ($data['order'] as $target_id) {
        $entity->children->appendItem($target_id);
      }
      foreach ($entity->children as $item) {
        $item->entity->parent->entity = $entity;
        $item->entity->save();
      }
      $entity->saveEdit();
    }
  }

}
