<?php

namespace Drupal\pagedesigner\Plugin\pagedesigner\Handler;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\HandlerPluginBase;
/**
 * Process entities of type "container".
 *
 * @PagedesignerHandler(
 *   id = "container",
 *   name = @Translation("Container render"),
 *   types = {
 *     "container",
 *   },
 * )
 */
class Container extends HandlerPluginBase {

  /**
   * {@inheritdoc}
   */
  public function renderForPublic(Element $entity, &$build) {
    $entity = $entity->loadNewestPublished();
    if ($entity != NULL) {
      foreach ($entity->children as $item) {
        if ($item->entity != NULL) {
          $listBuild[] = $this->elementHandler->renderForPublic($item->entity);
        }
      }
      $listBuild['#prefix'] = '<section class="pd-content pd-live container-fluid">';
      $listBuild['#suffix'] = '</section>';
      $build = $listBuild + $build;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function render(Element $entity, &$build = []) {
    foreach ($entity->children as $item) {
      if ($item->entity != NULL) {
        $listBuild[] = $this->elementHandler->render($item->entity);
      }
    }
    $listBuild['#prefix'] = '<section class="pd-content pd-live container-fluid">';
    $listBuild['#suffix'] = '</section>';
    $build = $listBuild + $build;
  }

  /**
   * {@inheritdoc}
   */
  public function renderForEdit(Element $entity, &$build = []) {
    foreach ($entity->children as $item) {
      if ($item->entity != NULL) {
        $listBuild[] = $this->elementHandler->renderForEdit($item->entity);
      }
    }
    $listBuild['#prefix'] = '<section data-grapes-block="content" data-gjs-draggable="false" data-gjs-droppable="true" data-entity-id="' . $entity->id() . '" data-gjs-type="container" class="pd-content pd-edit container-fluid">';
    $listBuild['#suffix'] = '</section>';
    $build = $listBuild + $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getContent(Element $entity, &$list = []) {
    foreach ($entity->children as $item) {
      if ($item->entity != NULL && ($child = $item->entity->loadNewestPublished()) != NULL) {
        $this->elementHandler->getContent($child, $list);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, &$result = []) {
    $data = [];
    foreach ($entity->children as $item) {
      $data[] = $item->entity->id();
    }
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, $data) {
    if (isset($data['order'])) {
      $entity->children->setValue([]);
      foreach ($data['order'] as $target_id) {
        $entity->children->appendItem($target_id);
      }
      $entity->saveEdit();
    }
  }

}
