<?php

namespace Drupal\pagedesigner\Service;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\PagedesignerService;

/**
 *
 */
class StateChanger extends PagedesignerService {

  /**
   * Publish an entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityBase $entity
   *
   * @return void
   */
  public function publish(ContentEntityBase $entity = NULL) {
    if ($entity == NULL) {
      return $this;
    }
    $fields = $this->getPagedesignerFields($entity);
    foreach ($fields as $field) {
      $container = $this->getContainer($entity, $field->getName());
      $this->_output .= $this->getHandler()->publish($container);
    }
    return $this;
  }

  /**
   * Unpublish an entity.
   *
   * @param \Drupal\Core\Entity\ContentEntityBase $entity
   *
   * @return void
   */
  public function unpublish(ContentEntityBase $entity = NULL) {
    if ($entity == NULL) {
      return $this;
    }
    $fields = $this->getPagedesignerFields($entity);
    foreach ($fields as $field) {
      $container = $this->getContainer($entity, $field->getName());
      $this->_output = $this->getHandler()->unpublish($container);
    }
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function copy(Element $entity, Element $container = NULL) {
    if ($entity == NULL) {
      return $this;
    }
    $clone = $this->getHandler()->copy($entity, $container);
    $this->_output = $clone;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function generate(ContentEntityBase $entity = NULL) {
    if ($entity == NULL) {
      return $this;
    }
    $this->_output = $this->getContainer($entity)->id();
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function delete(ContentEntityBase $entity = NULL) {
    if ($entity == NULL) {
      return $this;
    }
    $fields = $this->getPagedesignerFields($entity);
    foreach ($fields as $field) {
      $container = $this->getContainer($entity, $field->getName());
      $this->_output = $this->getHandler()->delete($container);
    }
    return $this;
  }

}
