<?php

namespace Drupal\Tests\pagedesigner\Kernel\HandlerTests;

use Drupal\Core\Render\Markup;
use Drupal\editor\Entity\Editor;

/**
 * Test the "html" handler with a predefined entity defintion.
 *
 * Tests serializing, getting and rendering of the entity.
 *
 * @ignore We have to add the pagedesigner editor to the test environment first.
 * @todo Add the pagedesigner editor config in setUp. Rename class to HTMLHandlerTest and remove abstract keyword afterwards.
 * @group pagedesigner
 */
abstract class HTMLHandlerTestCase extends FieldHandlerTestBase {

  /**
   * Define the properties of the entity.
   *
   * @var array
   */
  protected $entityDefinition = ['type' => 'html', 'name' => 'content', 'langcode' => 'en', 'field_content' => ['value' => 'some test data']];

  /**
   * Define handler to be tested.
   *
   * @var string
   */
  protected $handlerId = 'html';

  /**
   * {@inheritdoc}
   *
   * @todo Add the pagedesigner editor config to the environment.
   */
  public function setUp() {
    self::$modules[] = 'editor';
    parent::setUp();
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, assert the returned value is equal to the given value.
   */
  protected function serializeTest() {
    $result = parent::serializeTest();

    $this->assertTrue($result[0] == $this->entityDefinition['field_content']['value']);
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, assert the returned value is equal to the given value.
   */
  protected function getTest() {
    $value = parent::getTest();
    $this->assertTrue($value == $this->_getFormattedContent());
  }

  /**
   * {@inheritdoc}
   *
   * Additionally, check the render array schema and content.
   */
  protected function renderTest() {
    $build = parent::renderTest();
    $this->assertTrue($build['#markup'] == ['markup' => ['#markup' => Markup::create($this->_getFormattedContent())]]);
  }

  /**
   * Helper function to format the given value.
   *
   * @return string
   *   The formatted field_content value.
   */
  protected function _getFormattedContent() {
    $formatId = Editor::load('pagedesigner')->getFilterFormat()->id();
    $build = [
      '#type' => 'processed_text',
      '#text' => $this->$entityDefinition['field_content']['value'],
      '#format' => $formatId,
      '#filter_types_to_skip' => [],
      '#langcode' => $this->$entityDefinition['langcode'],
    ];
    return \Drupal::service('renderer')->renderPlain($build);
  }

}
